@@ -55,6 +55,7 @@ bool contains_plot_or_save(const std::string &str);
 void base_from_string(std::string str, int &base, Number &nbase, bool input_base = false);
 long int get_fixed_denominator_qt(const std::string &str, int &to_fraction, const QString &localized_fraction, bool qalc_command = false);
 bool is_equation_solutions(const MathStructure &m);
+void fix_expression(std::string &str);
 
 #ifndef CLOCK_MONOTONIC
 #	define PREPARE_TIMECHECK(ms) \
@@ -101,6 +102,14 @@ enum {
 	CLEAR_EXPRESSION
 };
 
+enum {
+	HISTORY_EXPRESSION_TYPE_PARSED,
+	HISTORY_EXPRESSION_TYPE_ENTERED,
+	HISTORY_EXPRESSION_TYPE_ENTERED_AND_PARSED,
+	HISTORY_EXPRESSION_TYPE_PARSED_COMPACT,
+	HISTORY_EXPRESSION_TYPE_ENTERED_AND_PARSED_COMPACT
+};
+
 typedef enum {
 	SHORTCUT_TYPE_FUNCTION,
 	SHORTCUT_TYPE_FUNCTION_WITH_DIALOG,
@@ -242,6 +251,7 @@ class QalculateQtSettings : QObject {
 		void setCustomAngleUnit();
 		void setDefaultCurrency();
 		QIcon loadColoredIcon(const QString &str, QWidget*);
+		bool useColoredIcon(QWidget*);
 		bool checkExchangeRates(QWidget *parent);
 		void fetchExchangeRates(int timeout, int n = -1, QWidget *parent = NULL);
 		bool displayMessages(QWidget *parent);
@@ -267,6 +277,8 @@ class QalculateQtSettings : QObject {
 		PrintOptions printops;
 		bool complex_angle_form, dot_question_asked, implicit_question_asked, assumptions_warning_shown, adaptive_interval_display, tc_set, rpn_mode, chain_mode, caret_as_xor, ignore_locale, do_imaginary_j, fetch_exchange_rates_at_startup, always_on_top, display_expression_status, prefixes_default, rpn_keys, sinc_set;
 		bool automatic_digit_grouping;
+		bool custom_digit_grouping, custom_digit_group_changed;
+		std::string custom_digit_group_separator, custom_digit_group_format, saved_local_dgs, saved_local_dgf;
 		int simplified_percentage;
 		bool programming_base_changed;
 		int previous_precision;
@@ -276,6 +288,7 @@ class QalculateQtSettings : QObject {
 		int allow_multiple_instances;
 		int decimal_comma, dual_fraction, dual_approximation, auto_update_exchange_rates, title_type;
 		int completion_delay, expression_status_delay, auto_calculate_delay;
+		bool adaptive_autocalc_delay;
 		int completion_min, completion_min2;
 		QString style;
 		int palette;
@@ -299,7 +312,7 @@ class QalculateQtSettings : QObject {
 		int toolbar_style;
 		int show_keypad;
 		int show_bases;
-		bool hide_numpad;
+		bool hide_numpad, show_custom_keypad_column;
 		bool keep_function_dialog_open;
 		bool save_defs_on_exit, save_mode_on_exit, clear_history_on_exit;
 		int max_history_lines;
