@@ -82,7 +82,7 @@ class QalculateWindow : public QMainWindow {
 		ExpressionEdit *expressionEdit;
 		HistoryView *historyView;
 		QSplitter *ehSplitter;
-		QLabel *statusLabel;
+		QLabel *statusLabelLeft, *statusLabelRight;
 		PreferencesDialog *preferencesDialog;
 		DataSetsDialog *datasetsDialog;
 		FunctionsDialog *functionsDialog;
@@ -105,7 +105,7 @@ class QalculateWindow : public QMainWindow {
 		QToolBar *tb;
 		QToolButton *menuAction_t, *modeAction_t, *keypadAction_t, *storeAction_t, *functionsAction_t, *unitsAction_t, *toAction_t;
 		QMenu *tmenu, *basesMenu;
-		QAction *plotAction_t, *basesAction, *customOutputBaseAction, *customInputBaseAction, *newVariableAction, *newFunctionAction, *variablesAction, *functionsAction, *unitsAction, *datasetsAction, *plotAction, *fpAction, *calendarsAction, *percentageAction, *periodicTableAction, *exratesAction, *quitAction, *helpAction, *keypadAction, *rpnAction, *chainAction, *gKeypadAction, *pKeypadAction, *xKeypadAction, *cKeypadAction, *nKeypadAction, *showNumpadAction, *resetKeypadPositionAction, *radAction, *degAction, *graAction, *normalAction, *sciAction, *engAction, *simpleAction, *copyBasesAction, *tbAction;
+		QAction *plotAction_t, *basesAction, *customOutputBaseAction, *customInputBaseAction, *newVariableAction, *newFunctionAction, *variablesAction, *functionsAction, *unitsAction, *datasetsAction, *plotAction, *fpAction, *calendarsAction, *percentageAction, *periodicTableAction, *exratesAction, *quitAction, *helpAction, *keypadAction, *rpnAction, *chainAction, *gKeypadAction, *pKeypadAction, *xKeypadAction, *cKeypadAction, *nKeypadAction, *showNumpadAction, *showCustomKeypadColumnAction, *resetKeypadPositionAction, *radAction, *degAction, *graAction, *normalAction, *sciAction, *engAction, *simpleAction, *copyBasesAction, *tbAction;
 		QMenu *recentVariablesMenu, *favouriteVariablesMenu, *variablesMenu, *functionsMenu, *recentFunctionsMenu, *favouriteFunctionsMenu, *unitsMenu, *recentUnitsMenu, *favouriteUnitsMenu, *angleMenu, *toMenu;
 		QAction *assumptionTypeActions[5], *assumptionSignActions[6];
 		QMenu *recentWSMenu;
@@ -128,6 +128,7 @@ class QalculateWindow : public QMainWindow {
 		void setResult(Prefix *prefix = NULL, bool update_history = true, bool update_parse = false, bool force = false, std::string transformation = "", bool do_stack = false, size_t stack_index = 0, bool register_moved = false, bool supress_dialog = false, bool calculate_selection = false);
 		void executeCommand(int command_type, bool show_result = true, std::string ceu_str = "", Unit *u = NULL, int run = 1);
 		void changeEvent(QEvent *e) override;
+		void resizeEvent(QResizeEvent *e) override;
 		bool warnAssumptions(MathStructure&, bool = false);
 		bool askTC(MathStructure&, bool = false);
 		bool askSinc(MathStructure&, bool = false);
@@ -192,6 +193,7 @@ class QalculateWindow : public QMainWindow {
 		void onStoreActivated();
 		void keypadTypeActivated();
 		void showNumpad(bool);
+		void showCustomKeypadColumn(bool);
 		void showSeparateKeypadMenuButtons(bool);
 		void resetKeypadPosition();
 		void onEMHTimeout();
@@ -215,9 +217,11 @@ class QalculateWindow : public QMainWindow {
 		void onTitleTypeChanged();
 		void onResultFontChanged();
 		void onExpressionFontChanged();
+		void onStatusFontChanged();
 		void onKeypadFontChanged();
 		void onAppFontChanged();
 		void onAppFontTimer();
+		void fixSplitterPos();
 		void angleUnitActivated();
 		void normalActivated();
 		void scientificActivated();
